

/* Define if you want tty's to be setgid() to the `tty' group */
#undef TTY_GID_SUPPORT

/* Define if you want readline support  */
#undef HAVE_READLINE

/* Define if you want readline support  */
#undef OPEN_SSH

/* Define if you want to drop root after mlock()  */
#undef DROP_ROOT

/* Define if you have _GNU_SOURCE getpt() */
#undef HAVE_GETPT

/* Define if you have a broken version of the `vsnprintf' function */
#undef HAVE_SNPRINTF_UNTERM
#undef HAVE_SNPRINTF_BUG
#undef HAVE_VSNPRINTF_UNTERM
#undef HAVE_VSNPRINTF_BUG

#undef HAVE_BROKEN_VSNPRINTF

/* Define possible pty types */
#undef PTYS_ARE_NUMERIC
#undef PTYS_ARE_PTMX
#undef PTYS_ARE_PTC
#undef PTYS_ARE__GETPTY
#undef PTYS_ARE_GETPTY
#undef PTYS_ARE_GETPT
#undef PTYS_ARE_CLONE
#undef PTYS_ARE_SEARCHED
